@@ -2,7 +2,13 @@ from __future__ import annotations
 import os.path
 from typing import Optional
 
-from git import Commit, InvalidGitRepositoryError, Repo
+from git import (
+	Commit,
+	GitCommandError,
+	InvalidGitRepositoryError,
+	NoSuchPathError,
+	Repo
+)
 
 from shulkr.config import get_config
 
@@ -15,6 +21,11 @@ def get_repo():
 
 		try:
 			repo = Repo(config.repo_path)
+
+		except NoSuchPathError:
+			print('Initializing git')
+			repo = Repo.init(config.repo_path)
+
 		except InvalidGitRepositoryError:
 			print('Initializing git')
 			repo = Repo.init(config.repo_path)
@@ -48,8 +59,8 @@ def head_has_versions() -> bool:
 		tags = repo.git.tag('--merged')
 		return len(tags) > 0
 
-	except ValueError as e:
-		if 'does not exist' in str(e):
+	except GitCommandError as e:
+		if 'fatal: malformed object name HEAD' in str(e):
 			return False
 
 		raise e
